@@ -5,7 +5,7 @@ import pandas as pd
 
 import pantab
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     df = pd.DataFrame(np.ones((100_000_000, 1)), columns=["a"])
     start = time.time()
     pantab.frame_to_hyper(df, "test.hyper", table="test")
